@@ -1166,6 +1166,11 @@ initpycurl(void)
 #if LIBCURL_VERSION_NUM >= MAKE_LIBCURL_VERSION(7, 80, 0)
     insint_c(d, "MAXLIFETIME_CONN", CURLOPT_MAXLIFETIME_CONN);
 #endif
+#if LIBCURL_VERSION_NUM >= MAKE_LIBCURL_VERSION(7, 80, 0)
+    insint_c(d, "PREREQFUNCTION", CURLOPT_PREREQFUNCTION);
+    insint_c(d, "PREREQFUNC_OK", CURL_PREREQFUNC_OK);
+    insint_c(d, "PREREQFUNC_ABORT", CURL_PREREQFUNC_ABORT);
+#endif
 
     insint_m(d, "M_TIMERFUNCTION", CURLMOPT_TIMERFUNCTION);
     insint_m(d, "M_SOCKETFUNCTION", CURLMOPT_SOCKETFUNCTION);
@@ -1251,6 +1256,9 @@ initpycurl(void)
 #if LIBCURL_VERSION_NUM >= MAKE_LIBCURL_VERSION(8, 2, 0)
     insint_c(d, "HAPROXY_CLIENT_IP", CURLOPT_HAPROXY_CLIENT_IP);
 #endif
+#if LIBCURL_VERSION_NUM >= MAKE_LIBCURL_VERSION(8, 8, 0)
+    insint_c(d, "ECH", CURLOPT_ECH);
+#endif
 
     /* curl_TimeCond: constants for setopt(TIMECONDITION, x) */
     insint_c(d, "TIMECONDITION_NONE", CURL_TIMECOND_NONE);
